键盘代码_ESC = 27
键盘代码_F1 = 112
键盘代码_F2 = 113
键盘代码_F3 = 114
键盘代码_F4 = 115
键盘代码_F5 = 116
键盘代码_F6 = 117
键盘代码_F7 = 118
键盘代码_F8 = 119
键盘代码_F9 = 120
键盘代码_F10 = 121
键盘代码_F11 = 122
键盘代码_F12 = 123
键盘代码_数字0 = 48
键盘代码_数字1 = 49
键盘代码_数字2 = 50
键盘代码_数字3 = 51
键盘代码_数字4 = 52
键盘代码_数字5 = 53
键盘代码_数字6 = 54
键盘代码_数字7 = 55
键盘代码_数字8 = 56
键盘代码_数字9 = 57
键盘代码_A = 65
键盘代码_B = 66
键盘代码_C = 67
键盘代码_D = 68
键盘代码_E = 69
键盘代码_F = 70
键盘代码_G = 71
键盘代码_H = 72
键盘代码_I = 73
键盘代码_J = 74
键盘代码_K = 75
键盘代码_L = 76
键盘代码_M = 77
键盘代码_N = 78
键盘代码_O = 79
键盘代码_P = 80
键盘代码_Q = 81
键盘代码_R = 82
键盘代码_S = 83
键盘代码_T = 84
键盘代码_U = 85
键盘代码_V = 86
键盘代码_W = 87
键盘代码_X = 88
键盘代码_Y = 89
键盘代码_Z = 90
键盘代码_回车 = 13
键盘代码_空格 = 32
键盘代码_左Shift = 16
键盘代码_右Shift = 16
键盘代码_左Ctrl = 17
键盘代码_右Ctrl = 17
键盘代码_左Alt = 18
键盘代码_右Alt = 18
键盘代码_Tab = 9
键盘代码_Backspace = 8
键盘代码_Insert = 45
键盘代码_Delete = 46
键盘代码_Home = 36
键盘代码_End = 35
键盘代码_PageUp = 33
键盘代码_PageDown = 34
键盘代码_向上箭头 = 38
键盘代码_向下箭头 = 40
键盘代码_向左箭头 = 37
键盘代码_向右箭头 = 39